@@ -21,8 +21,10 @@
 import datetime
 import itertools
 import json
+import warnings
 
 import croniter
+import debtcollector
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import netutils
@@ -39,11 +41,10 @@ from wsme import types as wtypes
 import wsmeext.pecan as wsme_pecan
 
 import aodh
-from aodh.api.controllers.v2.alarm_rules import combination
 from aodh.api.controllers.v2 import base
 from aodh.api.controllers.v2 import utils as v2_utils
 from aodh.api import rbac
-from aodh.i18n import _, _LI, _LE
+from aodh.i18n import _
 from aodh import keystone_client
 from aodh import messaging
 from aodh import notifier
@@ -73,6 +74,9 @@ state_kind_enum = wtypes.Enum(str, *state_kind)
 severity_kind = ["low", "moderate", "critical"]
 severity_kind_enum = wtypes.Enum(str, *severity_kind)
 
+ALARM_REASON_DEFAULT = "Not evaluated yet"
+ALARM_REASON_MANUAL = "Manually set via API"
+
 
 class OverQuota(base.ClientSideError):
     def __init__(self, data):
@@ -184,13 +188,7 @@ ACTIONS_SCHEMA = extension.ExtensionManager(
 
 
 class Alarm(base.Base):
-    """Representation of an alarm.
-
-    .. note::
-        combination_rule and threshold_rule are mutually exclusive. The *type*
-        of the alarm should be set to *threshold* or *combination* and the
-        appropriate rule should be filled.
-    """
+    """Representation of an alarm."""
 
     alarm_id = wtypes.text
     "The UUID of the alarm"
@@ -255,6 +253,9 @@ class Alarm(base.Base):
     state_timestamp = datetime.datetime
     "The date of the last alarm state changed"
 
+    state_reason = wsme.wsattr(wtypes.text, default=ALARM_REASON_DEFAULT)
+    "The reason of the current state"
+
     severity = base.AdvEnum('severity', str, *severity_kind,
                             default='low')
     "The severity of the alarm"
@@ -272,6 +273,12 @@ class Alarm(base.Base):
 
     @staticmethod
     def validate(alarm):
+        if alarm.type == 'threshold':
+            warnings.simplefilter("always")
+            debtcollector.deprecate(
+                "Ceilometer's API is deprecated as of Ocata. Therefore, "
+                " threshold rule alarms are no longer supported.",
+                version="5.0.0")
 
         Alarm.check_rule(alarm)
         Alarm.check_alarm_actions(alarm)
@@ -289,10 +296,6 @@ class Alarm(base.Base):
 
     @staticmethod
     def check_rule(alarm):
-        if (not pecan.request.cfg.api.enable_combination_alarms
-           and alarm.type == 'combination'):
-            raise base.ClientSideError("Unavailable alarm type")
-
         rule = '%s_rule' % alarm.type
         if getattr(alarm, rule) in (wtypes.Unset, None):
             error = _("%(rule)s must be set for %(type)s"
@@ -321,8 +324,8 @@ class Alarm(base.Base):
 
             action_set = set(actions)
             if len(actions) != len(action_set):
-                LOG.info(_LI('duplicate actions are found: %s, '
-                             'remove duplicate ones'), actions)
+                LOG.info('duplicate actions are found: %s, '
+                         'remove duplicate ones', actions)
                 actions = list(action_set)
                 setattr(alarm, actions_name, actions)
 
@@ -354,7 +357,7 @@ class Alarm(base.Base):
         return cls(alarm_id=None,
                    name="SwiftObjectAlarm",
                    description="An alarm",
-                   type='combination',
+                   type='threshold',
                    time_constraints=[AlarmTimeConstraint.sample().as_dict()],
                    user_id="c96c887c216949acbdfbd8b494863567",
                    project_id="c96c887c216949acbdfbd8b494863567",
@@ -362,12 +365,12 @@ class Alarm(base.Base):
                    timestamp=datetime.datetime(2015, 1, 1, 12, 0, 0, 0),
                    state="ok",
                    severity="moderate",
+                   state_reason="threshold over 90%",
                    state_timestamp=datetime.datetime(2015, 1, 1, 12, 0, 0, 0),
                    ok_actions=["http://site:8000/ok"],
                    alarm_actions=["http://site:8000/alarm"],
                    insufficient_data_actions=["http://site:8000/nodata"],
                    repeat_actions=False,
-                   combination_rule=combination.AlarmCombinationRule.sample(),
                    )
 
     def as_dict(self, db_model):
@@ -625,8 +628,10 @@ class AlarmController(rest.RestController):
         data.timestamp = now
         if alarm_in.state != data.state:
             data.state_timestamp = now
+            data.state_reason = ALARM_REASON_MANUAL
         else:
             data.state_timestamp = alarm_in.state_timestamp
+            data.state_reason = alarm_in.state_reason
 
         ALARMS_RULES[data.type].plugin.update_hook(data)
 
@@ -637,7 +642,7 @@ class AlarmController(rest.RestController):
         try:
             alarm_in = models.Alarm(**updated_alarm)
         except Exception:
-            LOG.exception(_LE("Error while putting alarm: %s"), updated_alarm)
+            LOG.exception("Error while putting alarm: %s", updated_alarm)
             raise base.ClientSideError(_("Alarm incorrect"))
 
         alarm = pecan.request.storage.update_alarm(alarm_in)
@@ -704,8 +709,10 @@ class AlarmController(rest.RestController):
         now = timeutils.utcnow()
         alarm.state = state
         alarm.state_timestamp = now
+        alarm.state_reason = ALARM_REASON_MANUAL
         alarm = pecan.request.storage.update_alarm(alarm)
-        change = {'state': alarm.state}
+        change = {'state': alarm.state,
+                  'state_reason': alarm.state_reason}
         self._record_change(change, now, on_behalf_of=alarm.project_id,
                             type=models.AlarmChange.STATE_TRANSITION)
         return alarm.state
@@ -790,6 +797,7 @@ class AlarmsController(rest.RestController):
 
         data.timestamp = now
         data.state_timestamp = now
+        data.state_reason = ALARM_REASON_DEFAULT
 
         ALARMS_RULES[data.type].plugin.create_hook(data)
 
@@ -800,7 +808,7 @@ class AlarmsController(rest.RestController):
         try:
             alarm_in = models.Alarm(**change)
         except Exception:
-            LOG.exception(_LE("Error while posting alarm: %s"), change)
+            LOG.exception("Error while posting alarm: %s", change)
             raise base.ClientSideError(_("Alarm incorrect"))
 
         alarm = conn.create_alarm(alarm_in)
