@@ -34,8 +34,9 @@ class GnocchiBase(threshold.ThresholdEvaluator):
         super(GnocchiBase, self).__init__(conf)
         self._gnocchi_client = client.Client(
             '1', keystone_client.get_session(conf),
-            interface=conf.service_credentials.interface,
-            region_name=conf.service_credentials.region_name)
+            adapter_options={
+                'interface': conf.service_credentials.interface,
+                'region_name': conf.service_credentials.region_name})
 
     @staticmethod
     def _sanitize(rule, statistics):
@@ -61,6 +62,7 @@ class GnocchiResourceThresholdEvaluator(GnocchiBase):
         try:
             return self._gnocchi_client.metric.get_measures(
                 metric=rule['metric'],
+                granularity=rule['granularity'],
                 start=start, stop=end,
                 resource_id=rule['resource_id'],
                 aggregation=rule['aggregation_method'])
@@ -101,6 +103,7 @@ class GnocchiAggregationMetricsThresholdEvaluator(GnocchiBase):
             #   https://bugs.launchpad.net/gnocchi/+bug/1479429
             return self._gnocchi_client.metric.aggregation(
                 metrics=rule['metrics'],
+                granularity=rule['granularity'],
                 start=start, stop=end,
                 aggregation=rule['aggregation_method'],
                 needed_overlap=0)
@@ -136,6 +139,7 @@ class GnocchiAggregationResourcesThresholdEvaluator(GnocchiBase):
         try:
             return self._gnocchi_client.metric.aggregation(
                 metrics=rule['metric'],
+                granularity=rule['granularity'],
                 query=jsonutils.loads(rule['query']),
                 resource_type=rule["resource_type"],
                 start=start, stop=end,
