@@ -19,7 +19,6 @@ from oslo_config import cfg
 from oslo_log import log
 import six.moves.urllib.parse as urlparse
 
-from aodh.i18n import _LE, _LI
 from aodh import keystone_client
 from aodh import notifier
 from aodh.notifier import trust
@@ -41,17 +40,17 @@ class ZaqarAlarmNotifier(notifier.AlarmNotifier):
     to an existing Zaqar queue with a pre-signed URL.
 
     To create a new subscription in the service project, use a notification URL
-    of the form:
+    of the form::
 
-        zaqar://?topic=example&subscriber=test@example.com&ttl=3600
+        zaqar://?topic=example&subscriber=mailto%3A//test%40example.com&ttl=3600
 
-    Multiple subscribers are allowed. ``ttl` is the time to live of the
+    Multiple subscribers are allowed. ``ttl`` is the time to live of the
     subscription. The queue will be created automatically, in the service
     project, with a name based on the topic and the alarm ID.
 
     To use a pre-signed URL for an existing queue, use a notification URL with
     the scheme ``zaqar://`` and the pre-signing data from Zaqar in the query
-    string:
+    string::
 
         zaqar://?queue_name=example&project_id=foo&
                  paths=/messages&methods=POST&expires=1970-01-01T00:00Z&
@@ -75,9 +74,9 @@ class ZaqarAlarmNotifier(notifier.AlarmNotifier):
                                                       interface=endpoint_type)
                 self._zendpoint = z_endpoint.url
             except Exception:
-                LOG.error(_LE("Aodh was configured to use zaqar:// action,"
-                              " but Zaqar endpoint could not be found in"
-                              " Keystone service catalog."))
+                LOG.error("Aodh was configured to use zaqar:// action,"
+                          " but Zaqar endpoint could not be found in"
+                          " Keystone service catalog.")
         return self._zendpoint
 
     def _get_client_conf(self):
@@ -101,7 +100,7 @@ class ZaqarAlarmNotifier(notifier.AlarmNotifier):
             return zaqar_client.Client(self._get_endpoint(),
                                        version=2, conf=conf)
         except Exception:
-            LOG.error(_LE("Failed to connect to Zaqar service "),
+            LOG.error("Failed to connect to Zaqar service ",
                       exc_info=True)
 
     def _get_presigned_client_conf(self, queue_info):
@@ -130,16 +129,16 @@ class ZaqarAlarmNotifier(notifier.AlarmNotifier):
 
     def notify(self, action, alarm_id, alarm_name, severity, previous,
                current, reason, reason_data, headers=None):
-        LOG.info(_LI(
+        LOG.info(
             "Notifying alarm %(alarm_name)s %(alarm_id)s of %(severity)s "
             "priority from %(previous)s to %(current)s with action %(action)s"
-            " because %(reason)s.") % ({'alarm_name': alarm_name,
-                                        'alarm_id': alarm_id,
-                                        'severity': severity,
-                                        'previous': previous,
-                                        'current': current,
-                                        'action': action,
-                                        'reason': reason}))
+            " because %(reason)s." % ({'alarm_name': alarm_name,
+                                       'alarm_id': alarm_id,
+                                       'severity': severity,
+                                       'previous': previous,
+                                       'current': current,
+                                       'action': action,
+                                       'reason': reason}))
         body = {'alarm_name': alarm_name, 'alarm_id': alarm_id,
                 'severity': severity, 'previous': previous,
                 'current': current, 'reason': reason,
@@ -182,11 +181,11 @@ class ZaqarAlarmNotifier(notifier.AlarmNotifier):
             # post the message to the queue
             queue.post(message)
         except IndexError:
-            LOG.error(_LE("Required query option missing in action %s"),
+            LOG.error("Required query option missing in action %s",
                       action)
         except Exception:
-            LOG.error(_LE("Unknown error occurred; Failed to post message to"
-                          " Zaqar queue"),
+            LOG.error("Unknown error occurred; Failed to post message to"
+                      " Zaqar queue",
                       exc_info=True)
 
 
@@ -212,8 +211,8 @@ class TrustZaqarAlarmNotifier(trust.TrustAlarmNotifierMixin,
         try:
             queue_name = queue_info.get('queue_name')[-1]
         except IndexError:
-            LOG.error(_LE("Required 'queue_name' query option missing in"
-                          " action %s"),
+            LOG.error("Required 'queue_name' query option missing in"
+                      " action %s",
                       action)
             return
 
@@ -223,6 +222,6 @@ class TrustZaqarAlarmNotifier(trust.TrustAlarmNotifierMixin,
             queue = client.queue(queue_name)
             queue.post(message)
         except Exception:
-            LOG.error(_LE("Unknown error occurred; Failed to post message to"
-                          " Zaqar queue"),
+            LOG.error("Unknown error occurred; Failed to post message to"
+                      " Zaqar queue",
                       exc_info=True)
