@@ -56,6 +56,7 @@ class AlarmTestBase(DBTestBase):
                                      user_id='me',
                                      project_id='and-da-boys',
                                      state="insufficient data",
+                                     state_reason="insufficient data",
                                      state_timestamp=constants.MIN_DATETIME,
                                      ok_actions=[],
                                      alarm_actions=['http://nowhere/alarms'],
@@ -85,6 +86,7 @@ class AlarmTestBase(DBTestBase):
                                      user_id='me',
                                      project_id='and-da-boys',
                                      state="insufficient data",
+                                     state_reason="insufficient data",
                                      state_timestamp=constants.MIN_DATETIME,
                                      ok_actions=[],
                                      alarm_actions=['http://nowhere/alarms'],
@@ -112,6 +114,7 @@ class AlarmTestBase(DBTestBase):
                                      user_id='me',
                                      project_id='and-da-boys',
                                      state="insufficient data",
+                                     state_reason="insufficient data",
                                      state_timestamp=constants.MIN_DATETIME,
                                      ok_actions=[],
                                      alarm_actions=['http://nowhere/alarms'],
@@ -174,8 +177,6 @@ class AlarmTest(AlarmTestBase):
         self.add_some_alarms()
         alarms = list(self.alarm_conn.get_alarms(alarm_type='threshold'))
         self.assertEqual(3, len(alarms))
-        alarms = list(self.alarm_conn.get_alarms(alarm_type='combination'))
-        self.assertEqual(0, len(alarms))
 
     def test_list_excluded_by_name(self):
         self.add_some_alarms()
@@ -221,6 +222,7 @@ class AlarmTest(AlarmTestBase):
                                  user_id='bla',
                                  project_id='ffo',
                                  state="insufficient data",
+                                 state_reason="insufficient data",
                                  state_timestamp=constants.MIN_DATETIME,
                                  ok_actions=[],
                                  alarm_actions=[],
