@@ -14,10 +14,10 @@
 """
 
 from ceilometerclient.v2 import statistics
+import fixtures
 import mock
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-from oslotest import mockpatch
 import six
 from six import moves
 
@@ -32,7 +32,7 @@ class BaseCompositeEvaluate(base.TestEvaluatorBase):
     EVALUATOR = composite.CompositeEvaluator
 
     def setUp(self):
-        self.client = self.useFixture(mockpatch.Patch(
+        self.client = self.useFixture(fixtures.MockPatch(
             'aodh.evaluator.gnocchi.client'
         )).mock.Client.return_value
         super(BaseCompositeEvaluate, self).setUp()
@@ -170,6 +170,7 @@ class CompositeTest(BaseCompositeEvaluate):
                          project_id='fake_project',
                          alarm_id=uuidutils.generate_uuid(),
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
@@ -190,6 +191,7 @@ class CompositeTest(BaseCompositeEvaluate):
                          user_id='fake_user',
                          project_id='fake_project',
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
@@ -211,6 +213,7 @@ class CompositeTest(BaseCompositeEvaluate):
                          user_id='fake_user',
                          project_id='fake_project',
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
@@ -233,6 +236,7 @@ class CompositeTest(BaseCompositeEvaluate):
                          project_id='fake_project',
                          alarm_id=uuidutils.generate_uuid(),
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
@@ -456,6 +460,7 @@ class OtherCompositeTest(BaseCompositeEvaluate):
                          user_id='fake_user',
                          project_id='fake_project',
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=['log://'],
